====
unet
====


.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.3352316.svg
        :target: https://doi.org/10.5281/zenodo.3352316
        :alt: DOI

.. image:: https://img.shields.io/badge/License-MIT-yellow.svg
        :target: https://opensource.org/licenses/MIT
        :alt: License

.. image:: https://img.shields.io/pypi/v/unet.svg
        :target: https://pypi.python.org/pypi/unet

.. image:: https://img.shields.io/travis/fepegar/unet.svg
        :target: https://travis-ci.org/fepegar/unet

.. image:: https://readthedocs.org/projects/unet/badge/?version=latest
        :target: https://unet.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/fepegar/unet/shield.svg
     :target: https://pyup.io/repos/github/fepegar/unet/
     :alt: Updates



PyTorch implementation of 2D and 3D U-Net


* Free software: MIT license
* Documentation: https://unet.readthedocs.io.


Features
--------

* TODO

Credits
-------

If you used this code for your research, please cite this repository using the
information available on its
`Zenodo entry <https://doi.org/10.5281/zenodo.3352316>`_.


This package was created with Cookiecutter_
and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
